=======
Credits
=======

Development Lead
----------------

* Blas Moyano <bmoyano@infobytesec.com>
* Eric Horvat <eric.nahuel.horvt@gmail.com>
* Nahuel Alonso <naloso@faradaysec.com>

Contributors
------------

None yet. Why not be the first?
